@@ -404,8 +404,13 @@ class HTTPResponse(Response):
                 return
         cookie = Cookie(app.sessionName(trans), identifier)
         cookie.setPath(app.sessionCookiePath(trans))
-        if trans.request().isSecure():
+        if request.isSecure():
             cookie.setSecure(app.setting('SecureSessionCookie'))
+        if app.setting('HttpOnlySessionCookie'):
+            cookie.setHttpOnly()
+        sameSite = app.setting('SameSiteSessionCookie')
+        if sameSite:
+            cookie.setSameSite(sameSite)
         self.addCookie(cookie)
         if debug:
             print('>> recordSession: Setting SID', identifier)
