@@ -3,6 +3,7 @@
 """Serve Webware for Python Application using the waitress WSGI server."""
 
 import argparse
+import logging
 
 
 def serve(args):
@@ -11,14 +12,14 @@ def serve(args):
     except ImportError as e:
         raise RuntimeError('Waitress server is not installed') from e
 
-    if args.browser:
-        scheme = args.url_scheme
-        host, port = args.host, args.port
-        prefix = args.url_prefix.strip('/')
-        if prefix:
-            prefix += '/'
-        url = f'{scheme}://{host}:{port}/{prefix}'
+    scheme = args.url_scheme
+    host, port = args.host, args.port
+    path = args.url_prefix.strip('/')
+    if path:
+        path = f'/{path}/'
+    url = f'{scheme}://{host}:{port}{path}'
 
+    if args.browser:
         import time
         import threading
         import webbrowser
@@ -68,7 +69,6 @@ def serve(args):
             'Cannot find Webware application.\nIs the current directory'
             ' the application working directory?') from e
 
-    print("Waitress serving Webware application...")
     args = vars(args)
     for arg in 'browser reload reload_interval prod wsgi_script'.split():
         del args[arg]
@@ -80,6 +80,14 @@ def serve(args):
             del args['trusted_proxy_count']
         if not args['trusted_proxy_headers']:
             del args['trusted_proxy_headers']
+    logLevel = args.pop('log_level')
+    if logLevel:
+        logLevel = logging.getLevelName(logLevel)
+        if isinstance(logLevel, int):
+            logger = logging.getLogger('waitress')
+            logger.setLevel(logLevel)
+
+    print(f"Waitress serving Webware application on {url}")
     serve(application, **args)
 
 
@@ -155,6 +163,13 @@ def addArguments(parser):
         help='The file path of the WSGI script',
         default='Scripts/WSGIScript.py',
     )
+    parser.add_argument(
+        '--log-level',
+        help='Logs output on the given level',
+        default=None,
+        choices=('DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL'),
+        type=str.upper
+    )
 
 
 def main(args=None):
